@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "jet" "1.2.0"
+(define-package "jet" "20240730.1228"
   "Emacs integration for jet Clojure tool."
   '((emacs     "27.1")
     (transient "0.3.7"))
